@@ -1,13 +1,17 @@
+use 5.10.1;
 use strict;
 use warnings;
 
 package Dist::Zilla::MintingProfile::DistIller::Basic;
 
-our $VERSION = '0.1204'; # VERSION
+our $VERSION = '0.1300'; # VERSION
 
 use Moose;
+use namespace::autoclean;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -22,7 +26,7 @@ Dist::Zilla::MintingProfile::DistIller::Basic
 
 =head1 VERSION
 
-Version 0.1204, released 2016-01-22.
+Version 0.1300, released 2016-01-29.
 
 =head1 SOURCE
 
