@@ -1,11 +1,13 @@
+use 5.10.1;
 use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::DistIller::MetaGeneratedBy;
 
-our $VERSION = '0.1204'; # VERSION
+our $VERSION = '0.1300'; # VERSION
 
 use Moose;
+use namespace::autoclean;
 with 'Dist::Zilla::Role::MetaProvider';
 
 use Dist::Iller;
@@ -18,7 +20,6 @@ sub metadata {
     };
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -35,7 +36,7 @@ Dist::Zilla::Plugin::DistIller::MetaGeneratedBy
 
 =head1 VERSION
 
-Version 0.1204, released 2016-01-22.
+Version 0.1300, released 2016-01-29.
 
 =head1 SOURCE
 
